@@ -24,6 +24,7 @@ use Doctrine\DBAL\Schema\Table;
 use Doctrine\DBAL\Tests\FunctionalTestCase;
 use Doctrine\DBAL\Tests\TestUtil;
 use Doctrine\DBAL\Types\Types;
+use PDO;
 
 use function array_change_key_case;
 
@@ -555,11 +556,10 @@ final class QueryBuilderTest extends FunctionalTestCase
      */
     private function prepareExpectedRows(array $rows): array
     {
-        if (! TestUtil::isDriverOneOf('ibm_db2', 'pdo_oci', 'pdo_sqlsrv', 'oci8')) {
-            return $rows;
-        }
-
-        if (! TestUtil::isDriverOneOf('ibm_db2')) {
+        if (
+            TestUtil::isDriverOneOf('pdo_oci', 'pdo_sqlsrv', 'oci8')
+            || (TestUtil::getConnectionParams()['driverOptions'][PDO::ATTR_STRINGIFY_FETCHES] ?? false) === true
+        ) {
             foreach ($rows as &$row) {
                 foreach ($row as &$value) {
                     $value = (string) $value;
@@ -567,12 +567,10 @@ final class QueryBuilderTest extends FunctionalTestCase
             }
         }
 
-        if (! TestUtil::isDriverOneOf('ibm_db2', 'pdo_oci', 'oci8')) {
-            return $rows;
-        }
-
-        foreach ($rows as &$row) {
-            $row = array_change_key_case($row, CASE_UPPER);
+        if (TestUtil::isDriverOneOf('ibm_db2', 'pdo_oci', 'oci8')) {
+            foreach ($rows as &$row) {
+                $row = array_change_key_case($row, CASE_UPPER);
+            }
         }
 
         return $rows;
